from django.db import models
from django.utils.translation import ugettext_lazy as _
from django_dzenlog.models import GeneralPost
from django.conf import settings

class LinkPost(GeneralPost):
    list_template             = 'dzenlog_link/list.html'
    detail_template           = 'dzenlog_link/detail.html'
    body_detail_template      = 'dzenlog_link/body_detail.html'
    body_list_template        = 'dzenlog_link/body_list.html'
    feed_description_template = 'dzenlog_link/text_feed_detail.html'

    url = models.URLField(_('URL'), verify_exists = not settings.DEBUG)
    description = models.TextField(_('URL\'s description'), max_length = 255)




from setuptools import setup, find_packages

setup(
    name = 'dzenlog-link',
    version = '0.1.0',
    description = 'This is a simple application to post links to the dzenlog.',
    keywords = 'django apps blogging dzenlog',
    license = 'New BSD License',
    author = 'Alexander Artemenko',
    author_email = 'svetlyak.40wt@gmail.com',
    url = 'http://github.com/svetlyak40wt/django-dzenlog-link/',
    install_requires = ['django-dzenlog>=0.2.0'],
    dependency_links = ['http://pypi.aartemenko.com/'],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Environment :: Plugins',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Programming Language :: Python',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
    packages = find_packages(exclude=['example*']),
    package_data = {
        'templates': ['*.html'],
    },
    include_package_data = True,
)

